#[repr(i32)]pub enum RedirectScheme {
UseSame = 0,
UseHttp = 1,
UseHttps = 2,
}Expand description
Scheme to use when building the Location header for a permanent redirect.
USE_SAME preserves the request scheme (default), USE_HTTP forces <http://,>
USE_HTTPS forces <https://.>
Variants
Implementations
Sourceimpl RedirectScheme
impl RedirectScheme
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.