#[repr(i32)]pub enum UdpHealthMode {
HealthOff = 0,
TcpProbe = 1,
UdpProbe = 2,
}Expand description
UDP backend health probe mode. HEALTH_OFF disables health checking; TCP_PROBE opens a non-blocking TCP connection to a companion port; UDP_PROBE sends an application datagram and waits for any reply.
Variants
Implementations
Sourceimpl UdpHealthMode
impl UdpHealthMode
Sourceimpl UdpHealthMode
impl UdpHealthMode
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.