pub struct AlpnProtocols {
pub values: Vec<String>,
}Expand description
Wrapper message to distinguish “absent” (preserve) from “present but empty”
(reset to default) for ALPN protocols. A bare repeated string cannot make
this distinction in proto2 since field absence is not detectable for repeated
scalars without a sentinel.
Fields
values: Vec<String>Trait Implementations
Sourceimpl Clone for AlpnProtocols
impl Clone for AlpnProtocols
Sourcefn clone(&self) -> AlpnProtocols
fn clone(&self) -> AlpnProtocols
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AlpnProtocols
impl Debug for AlpnProtocols
Sourceimpl Default for AlpnProtocols
impl Default for AlpnProtocols
Sourceimpl<'de> Deserialize<'de> for AlpnProtocols
impl<'de> Deserialize<'de> for AlpnProtocols
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for AlpnProtocols
impl Hash for AlpnProtocols
Sourceimpl Message for AlpnProtocols
impl Message for AlpnProtocols
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl Ord for AlpnProtocols
impl Ord for AlpnProtocols
Sourcefn cmp(&self, other: &AlpnProtocols) -> Ordering
fn cmp(&self, other: &AlpnProtocols) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for AlpnProtocols
impl PartialEq for AlpnProtocols
Sourcefn eq(&self, other: &AlpnProtocols) -> bool
fn eq(&self, other: &AlpnProtocols) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for AlpnProtocols
impl PartialOrd for AlpnProtocols
Sourceimpl Serialize for AlpnProtocols
impl Serialize for AlpnProtocols
impl Eq for AlpnProtocols
impl StructuralPartialEq for AlpnProtocols