pub struct HealthChecksList {
pub map: BTreeMap<String, HealthCheckConfig>,
}Fields
map: BTreeMap<String, HealthCheckConfig>Trait Implementations
Sourceimpl Clone for HealthChecksList
impl Clone for HealthChecksList
Sourcefn clone(&self) -> HealthChecksList
fn clone(&self) -> HealthChecksList
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HealthChecksList
impl Debug for HealthChecksList
Sourceimpl Default for HealthChecksList
impl Default for HealthChecksList
Sourceimpl<'de> Deserialize<'de> for HealthChecksList
impl<'de> Deserialize<'de> for HealthChecksList
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for HealthChecksList
impl Hash for HealthChecksList
Sourceimpl Message for HealthChecksList
impl Message for HealthChecksList
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl Ord for HealthChecksList
impl Ord for HealthChecksList
Sourcefn cmp(&self, other: &HealthChecksList) -> Ordering
fn cmp(&self, other: &HealthChecksList) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for HealthChecksList
impl PartialEq for HealthChecksList
Sourcefn eq(&self, other: &HealthChecksList) -> bool
fn eq(&self, other: &HealthChecksList) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for HealthChecksList
impl PartialOrd for HealthChecksList
Sourceimpl Serialize for HealthChecksList
impl Serialize for HealthChecksList
impl Eq for HealthChecksList
impl StructuralPartialEq for HealthChecksList