pub struct MaxConnectionsPerIpLimit {
pub limit: u64,
}Expand description
0 means unlimited (the feature is disabled). Returned by workers in
response to Request.query_max_connections_per_ip.
Fields
limit: u64Trait Implementations
Sourceimpl Clone for MaxConnectionsPerIpLimit
impl Clone for MaxConnectionsPerIpLimit
Sourcefn clone(&self) -> MaxConnectionsPerIpLimit
fn clone(&self) -> MaxConnectionsPerIpLimit
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MaxConnectionsPerIpLimit
impl Debug for MaxConnectionsPerIpLimit
Sourceimpl Default for MaxConnectionsPerIpLimit
impl Default for MaxConnectionsPerIpLimit
Sourceimpl<'de> Deserialize<'de> for MaxConnectionsPerIpLimit
impl<'de> Deserialize<'de> for MaxConnectionsPerIpLimit
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for MaxConnectionsPerIpLimit
impl Hash for MaxConnectionsPerIpLimit
Sourceimpl Message for MaxConnectionsPerIpLimit
impl Message for MaxConnectionsPerIpLimit
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl Ord for MaxConnectionsPerIpLimit
impl Ord for MaxConnectionsPerIpLimit
Sourcefn cmp(&self, other: &MaxConnectionsPerIpLimit) -> Ordering
fn cmp(&self, other: &MaxConnectionsPerIpLimit) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for MaxConnectionsPerIpLimit
impl PartialEq for MaxConnectionsPerIpLimit
Sourcefn eq(&self, other: &MaxConnectionsPerIpLimit) -> bool
fn eq(&self, other: &MaxConnectionsPerIpLimit) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for MaxConnectionsPerIpLimit
impl PartialOrd for MaxConnectionsPerIpLimit
Sourceimpl Serialize for MaxConnectionsPerIpLimit
impl Serialize for MaxConnectionsPerIpLimit
impl Copy for MaxConnectionsPerIpLimit
impl Eq for MaxConnectionsPerIpLimit
impl StructuralPartialEq for MaxConnectionsPerIpLimit