pub struct QueryMaxConnectionsPerIp {}Trait Implementations
Sourceimpl Clone for QueryMaxConnectionsPerIp
impl Clone for QueryMaxConnectionsPerIp
Sourcefn clone(&self) -> QueryMaxConnectionsPerIp
fn clone(&self) -> QueryMaxConnectionsPerIp
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for QueryMaxConnectionsPerIp
impl Debug for QueryMaxConnectionsPerIp
Sourceimpl Default for QueryMaxConnectionsPerIp
impl Default for QueryMaxConnectionsPerIp
Sourceimpl<'de> Deserialize<'de> for QueryMaxConnectionsPerIp
impl<'de> Deserialize<'de> for QueryMaxConnectionsPerIp
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for QueryMaxConnectionsPerIp
impl Hash for QueryMaxConnectionsPerIp
Sourceimpl Message for QueryMaxConnectionsPerIp
impl Message for QueryMaxConnectionsPerIp
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl Ord for QueryMaxConnectionsPerIp
impl Ord for QueryMaxConnectionsPerIp
Sourcefn cmp(&self, other: &QueryMaxConnectionsPerIp) -> Ordering
fn cmp(&self, other: &QueryMaxConnectionsPerIp) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for QueryMaxConnectionsPerIp
impl PartialEq for QueryMaxConnectionsPerIp
Sourcefn eq(&self, other: &QueryMaxConnectionsPerIp) -> bool
fn eq(&self, other: &QueryMaxConnectionsPerIp) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for QueryMaxConnectionsPerIp
impl PartialOrd for QueryMaxConnectionsPerIp
Sourceimpl Serialize for QueryMaxConnectionsPerIp
impl Serialize for QueryMaxConnectionsPerIp
impl Copy for QueryMaxConnectionsPerIp
impl Eq for QueryMaxConnectionsPerIp
impl StructuralPartialEq for QueryMaxConnectionsPerIp