pub struct RequestUdpFrontend {
pub cluster_id: String,
pub address: SocketAddress,
pub tags: BTreeMap<String, String>,
}Fields
cluster_id: Stringaddress: SocketAddressthe socket address on which to listen for incoming datagrams
custom tags to identify the frontend in the access logs