pub struct UdpHealthConfig {
pub mode: Option<i32>,
pub tcp_port: Option<u32>,
pub rise: Option<u32>,
pub fall: Option<u32>,
pub fail_open: Option<bool>,
pub udp_probe_payload: Option<Vec<u8>>,
pub probe_interval_seconds: Option<u32>,
pub probe_timeout_seconds: Option<u32>,
}Expand description
Optional health-check configuration for a UDP cluster’s backends.
Fields
mode: Option<i32>probe mode; defaults to TCP_PROBE when a udp block is present
tcp_port: Option<u32>companion TCP probe port; unset = the backend data port
rise: Option<u32>consecutive successes before a backend is marked up
fall: Option<u32>consecutive failures before a backend is marked down
fail_open: Option<bool>when all backends are down, still forward (don’t drop the flow)
udp_probe_payload: Option<Vec<u8>>payload sent for a UDP_PROBE
probe_interval_seconds: Option<u32>delay between probes, in seconds
probe_timeout_seconds: Option<u32>per-probe response timeout, in seconds
Implementations
Sourceimpl UdpHealthConfig
impl UdpHealthConfig
Sourcepub fn mode(&self) -> UdpHealthMode
pub fn mode(&self) -> UdpHealthMode
Returns the enum value of mode, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_mode(&mut self, value: UdpHealthMode)
pub fn set_mode(&mut self, value: UdpHealthMode)
Sets mode to the provided enum value.
Sourcepub fn tcp_port(&self) -> u32
pub fn tcp_port(&self) -> u32
Returns the value of tcp_port, or the default value if tcp_port is unset.
Sourcepub fn fail_open(&self) -> bool
pub fn fail_open(&self) -> bool
Returns the value of fail_open, or the default value if fail_open is unset.
Sourcepub fn udp_probe_payload(&self) -> &[u8] ⓘ
pub fn udp_probe_payload(&self) -> &[u8] ⓘ
Returns the value of udp_probe_payload, or the default value if udp_probe_payload is unset.
Sourcepub fn probe_interval_seconds(&self) -> u32
pub fn probe_interval_seconds(&self) -> u32
Returns the value of probe_interval_seconds, or the default value if probe_interval_seconds is unset.
Sourcepub fn probe_timeout_seconds(&self) -> u32
pub fn probe_timeout_seconds(&self) -> u32
Returns the value of probe_timeout_seconds, or the default value if probe_timeout_seconds is unset.